BufferSegment class
A BufferSegment represents a range within a line.
Constructors
- BufferSegment(BufferRange range, int line, int? start, int? end)
-
const
Properties
- end → int?
-
The end position of this segment.
nullmeans the end of the line. Should be greater than or equal to start.final - hashCode → int
-
The hash code for this object.
no setteroverride
- line → int
-
The line that this segment resides on.
final
- range → BufferRange
-
The range that this segment belongs to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
The start position of this segment.
nullmeans the start of the line.final
Methods
-
isWithin(
CellOffset position) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override