CellAttr class abstract
Constructors
- CellAttr()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blink → const int
- bold → const int
- faint → const int
- inverse → const int
- invisible → const int
- italic → const int
- strikethrough → const int
- underline → const int
- underlineStyleCurly → const int
- underlineStyleDashed → const int
- underlineStyleDotted → const int
- underlineStyleDouble → const int
- underlineStyleNone → const int
- underlineStyleSingle → const int