CellData class

Constructors

CellData({required int foreground, required int background, required int flags, required int content, int underlineStyle = 0, int underlineColor = 0, int imageData = 0, int hyperlinkId = 0})
CellData.empty()
factory

Properties

background ↔ int
getter/setter pair
content ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
foreground ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasImage → bool
Check if cell has an image
no setter
hyperlinkId ↔ int
Hyperlink ID (0 = no hyperlink)
getter/setter pair
imageData ↔ int
Packed image data: upper 16 bits = image ID, lower 16 bits = placement ID
getter/setter pair
imageId → int
Get image ID from imageData
no setter
placementId → int
Get placement ID from imageData
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underlineColor ↔ int
Underline color encoded like foreground/background (type + value)
getter/setter pair
underlineStyle ↔ int
Underline style: 0=none, 1=single, 2=curly, 3=dotted, 4=dashed
getter/setter pair

Methods

getHash() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited