SearchCallback typedef
SearchCallback =
String Function()
Callback type for searching text in the terminal buffer.
Implementation
typedef SearchCallback = String Function();
Callback type for searching text in the terminal buffer.
typedef SearchCallback = String Function();