onTitleChange property
Function that is called when the program requests the terminal to change the title of the window.
Implementation
void Function(String title)? onTitleChange;
Function that is called when the program requests the terminal to change the title of the window.
void Function(String title)? onTitleChange;