TerminalHighlight class

A visual highlight on a range of terminal cells. Dispose the returned object to remove the highlight.

Constructors

TerminalHighlight(TerminalController owner, {required CellAnchor p1, required CellAnchor p2, required Color color})

Properties

color → Color
The color used to draw the highlight.
final
disposed → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
onDisposed → Event
no setterinherited
owner → TerminalController
The controller this highlight belongs to.
final
p1 → CellAnchor
Anchor at the start of the highlighted range.
final
p2 → CellAnchor
Anchor at the end of the highlighted range.
final
range → BufferRange?
Returns the range of the highlight. May be null if the anchors that define the highlight are not attached to the terminal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Disposable disposable) → void
inherited
registerCallback(void callback()) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited