TerminalMouseButton enum
Values
- left → const TerminalMouseButton
-
const TerminalMouseButton(id: 0) - middle → const TerminalMouseButton
-
const TerminalMouseButton(id: 1) - right → const TerminalMouseButton
-
const TerminalMouseButton(id: 2) - wheelUp → const TerminalMouseButton
-
const TerminalMouseButton(id: 64 + 4, isWheel: true) - wheelDown → const TerminalMouseButton
-
const TerminalMouseButton(id: 64 + 5, isWheel: true) - wheelLeft → const TerminalMouseButton
-
const TerminalMouseButton(id: 64 + 6, isWheel: true) - wheelRight → const TerminalMouseButton
-
const TerminalMouseButton(id: 64 + 7, isWheel: true)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
The id that is used to report a button press or release to the terminal.
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isWheel → bool
-
Whether this button is a mouse wheel button.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TerminalMouseButton> - A constant List of the values in this enum, in order of their declaration.