ui library

Enums

PointerInput
SearchOption
Options for search behavior.
SelectionMode
TerminalCursorType

Typedefs

CreateAnchorCallback = CellAnchor Function(CellOffset offset)
Callback type for creating a cell anchor from a position.
SearchCallback = String Function()
Callback type for searching text in the terminal buffer.