CursorStyle class
Constructors
Properties
- attrs ↔ int
-
getter/setter pair
- background ↔ int
-
getter/setter pair
- foreground ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hyperlinkId ↔ int
-
Hyperlink ID (0 = no hyperlink)
getter/setter pair
- isBlink → bool
-
no setter
- isBold → bool
-
no setter
- isFaint → bool
-
no setter
- isInverse → bool
-
no setter
- isInvisible → bool
-
no setter
- isItalis → bool
-
no setter
- isUnderline → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underlineColor ↔ int
-
Underline color encoded like foreground/background (type + value)
getter/setter pair
- underlineStyle ↔ int
-
Underline style: 0=none, 1=single, 2=double, 3=curly, 4=dotted, 5=dashed
getter/setter pair
Methods
-
copy(
) → CursorStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
resetBackgroundColor(
) → void -
resetForegroundColor(
) → void -
resetUnderlineColor(
) → void -
setBackgroundColor16(
int color) → void -
setBackgroundColor256(
int color) → void -
setBackgroundColorRgb(
int r, int g, int b) → void -
setBlink(
) → void -
setBold(
) → void -
setFaint(
) → void -
setForegroundColor16(
int color) → void -
setForegroundColor256(
int color) → void -
setForegroundColorRgb(
int r, int g, int b) → void -
setInverse(
) → void -
setInvisible(
) → void -
setItalic(
) → void -
setStrikethrough(
) → void -
setUnderline(
) → void -
setUnderlineColor256(
int color) → void -
setUnderlineColorRgb(
int r, int g, int b) → void -
setUnderlineStyle(
int style) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unsetBlink(
) → void -
unsetBold(
) → void -
unsetFaint(
) → void -
unsetInverse(
) → void -
unsetInvisible(
) → void -
unsetItalic(
) → void -
unsetStrikethrough(
) → void -
unsetUnderline(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- empty → CursorStyle
-
final